package fr.iutlan.avosavis;

import java.util.List;

import android.graphics.Color;
import android.support.v7.widget.RecyclerView;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;


public class AvisAdapter extends RecyclerView.Adapter<AvisView>
{
    // la liste affichée est copiée ici
    private final List<Avis> mListeAvis;

    // gestion des clics : sélection et menu contextuel
    private AdapterView.OnItemClickListener mItemClickListener;
    private int mClickedPosition = RecyclerView.NO_POSITION;
    private Avis mSelectedItem = null;


    public AvisAdapter(List<Avis> liste, AdapterView.OnItemClickListener itemClickListener)
    {
        mListeAvis = liste;
        mItemClickListener = itemClickListener;
    }


    @Override
    public int getItemCount()
    {
        return mListeAvis.size();
    }


    @Override
    public AvisView onCreateViewHolder(ViewGroup parent, int viewType)
    {
        return AvisView.createView(parent);
    }


    @Override
    public void onBindViewHolder(final AvisView holder, final int position)
    {
        // récupérer l'avis qui est à cette position
        final Avis avis = mListeAvis.get(position);
        if (avis == null) return;

        // afficher les informations de l'item dans les vues
        holder.setItem(avis);

        // identifiant de cet avis
        final long id = (long) position;

        // définir un écouteur pour les clics
        holder.itemView.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                // mettre à jour la mClickedPosition de cette vue
                setClickedPosition(position, avis);
                // appeler l'écouteur : c'est l'activité qui a créé cet adaptateur
                mItemClickListener.onItemClick(null, null, position, id);
            }
        });

        // définir un écouteur pour les clics longs (menus ou autre)
        holder.itemView.setOnLongClickListener(new View.OnLongClickListener() {
            @Override
            public boolean onLongClick(View v) {
                // mettre à jour la mClickedPosition de cette vue
                setClickedPosition(position, avis);
                // faire comme si on n'avait rien fait => le menu apparaîtra si c'est prévu
                return false;
            }
        });

        // accentuer la sélection
        holder.itemView.setBackgroundColor(mClickedPosition == position ? Color.LTGRAY : Color.TRANSPARENT);
    }


    /**
     * définit la position du clic et l'élément désigné
     */
    private void setClickedPosition(int position, Avis avis)
    {
        notifyItemChanged(mClickedPosition);
        mClickedPosition = position;
        mSelectedItem = avis;
        notifyItemChanged(mClickedPosition);
    }


    /**
     * retourne la position du clic
     */
    public int getClickedPosition()
    {
        return mClickedPosition;
    }


    /**
     * retourne l'élément désigné par le dernier clic sur la liste
     */
    public Avis getSelectedItem()
    {
        return mSelectedItem;
    }


    /**
     * efface la sélection, à employer quand l'élément a été supprimé de la liste
     */
    public void clearSelection()
    {
        notifyItemChanged(mClickedPosition);
        mClickedPosition = RecyclerView.NO_POSITION;
        mSelectedItem = null;
        notifyItemChanged(mClickedPosition);
    }
}
