package fr.iutlan.avosavis;

import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.Formatter;

import android.content.Intent;
import android.os.Bundle;
import android.support.v7.app.AppCompatActivity;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.widget.EditText;
import android.widget.RatingBar;
import android.widget.TextView;


public class EditActivity extends AppCompatActivity
{
    private static final String TAG = "avosavis";

    /// identifiant de l'item en cours d'édition, -1 si création
    public static final String PARAM_IDENTIFIANT = "identifiant";
    private long identifiant;

    /// contenu du layout
    private EditText etLibelle;
    private RatingBar rbNote;
    private TextView tvDate;

    @Override
    protected void onCreate(Bundle savedInstanceState)
    {
        // mettre en place l'interface
        super.onCreate(savedInstanceState);
        setContentView(R.layout.edit_activity);
        findViews();

        // obtenir l'identifiant de l'item à éditer, -1 si création
        Intent intent = getIntent();
        identifiant = intent.getLongExtra(PARAM_IDENTIFIANT, -1L);

        // titre de l'activité
        if (identifiant < 0) {
            setTitle(R.string.nouvel_avis);
        } else {
            setTitle(R.string.editer_avis);
        }

        // afficher les informations éditables (nom,distance) de la planète
        display();
    }


    /**
     * cherche les objets Java correspondant aux vues
     */
    private void findViews()
    {
        // FIXME en SDK 27, il n'est pas nécessaire de mettre ces cast (EditText), (TextView) et (RatingBar), donc les enlever
        etLibelle = (EditText) findViewById(R.id.item_avis_libelle);
        rbNote = (RatingBar) findViewById(R.id.item_avis_note);
        tvDate = (TextView) findViewById(R.id.item_avis_date);
    }


    /**
     * Cette méthode statique écrit une date dans un TextView JJ/MM/AAAA
     * @param tvDate TextView affecté
     * @param date qu'il faut mettre dans tvDate
     */
    public static void setDateToTextView(TextView tvDate, Date date)
    {
        if (date == null) return;
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(date);
        int day = calendar.get(Calendar.DAY_OF_MONTH);
        int month = calendar.get(Calendar.MONTH) + 1; // les mois sont décalés
        int year =  calendar.get(Calendar.YEAR);

        Formatter format = new Formatter();
        tvDate.setText(format.format("Le %02d/%02d/%04d", day, month, year).toString());
        format.close();
    }


    /**
     * Affiche l'item désigné par l'identifiant dans les vues de this
     */
    public void display()
    {
        // rien à afficher si l'item est en création
        if (identifiant < 0) return;

        // récupérer l'item désigné par l'identifiant
        AvosAvisApplication app = (AvosAvisApplication) getApplicationContext();
        ArrayList<Avis> liste = app.getListe();
        Avis avis = liste.get((int) identifiant);

        // afficher ses valeurs dans les vues
        etLibelle.setText(avis.getLibelle());
        rbNote.setRating(avis.getNote());
        setDateToTextView(tvDate, avis.getDate());
    }


    /**
     * Affecte les propriétés de l'item désigné par l'identifiant avec ce qu'il y a dans les vues
     */
    public void onValider()
    {
        // liste de l'application
        AvosAvisApplication app = (AvosAvisApplication) getApplicationContext();
        ArrayList<Avis> liste = app.getListe();

        // avis en cours d'édition ou de création
        Avis avis;
        if (identifiant < 0) {
            // créer un nouvel item
            avis = new Avis();
            liste.add(avis);
        } else {
            // récupérer l'item désigné par l'identifiant
            avis = liste.get((int) identifiant);
        }

        // récupérer les valeurs présentes dans les vues
        avis.setLibelle(etLibelle.getText().toString());
        avis.setNote(rbNote.getRating());

        // date = date actuelle, on ne peut pas mettre une autre (c'est volontaire)
        Calendar calendar = Calendar.getInstance();
        avis.setDate(calendar.getTime());

        // sortir avec succès
        setResult(RESULT_OK);
        finish();
    }


    /**
     * supprime l'item en cours d'édition
     */
    @SuppressWarnings("unused")
    private void onSupprimer()
    {
        // mode création ?
        if (identifiant < 0) {
            // cas particulier : création d'un item, le supprimer ne fait rien
            return;
        }
        Log.e(TAG, "onSupprimer");

        // TODO afficher un dialogue de confirmation

        // récupérer la liste
        AvosAvisApplication app = (AvosAvisApplication) getApplicationContext();
        ArrayList<Avis> liste = app.getListe();

        // supprimer l'élément
        liste.remove(EditActivity.this.identifiant);

        // TODO il y a quelque chose d'autre à faire
    }

    /*** Gestion du menu de la barre d'action en haut à droite ***/

    /**
     * appelée pour créer le menu de l'activité
     */
    @Override
    public boolean onCreateOptionsMenu(Menu menu)
    {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.edit, menu);
        return true;
    }

    /**
     * appelée quand on clique sur un élément de menu
     */
    @Override
    public boolean onOptionsItemSelected(MenuItem item)
    {
        switch (item.getItemId()) {

            case R.id.valider:
                // l'utilisateur a choisi le menu valider : retourner l'item et son identifiant à l'activité
                onValider();
                return true;

            case R.id.annuler:
                // l'utilisateur a choisi le menu annuler : terminer l'activité sans modifier la liste
                setResult(RESULT_CANCELED);
                finish();
                return true;

            // TODO rajouter un cas pour appeler la méthode onSupprimer

        }
        return super.onOptionsItemSelected(item);
    }
}
