package fr.iutlan.avosavis;

/**
 * Biblio : http://www.bignerdranch.com/blog/customizing-android-listview-rows-subclassing/
 */

import java.util.ArrayList;

import android.content.Intent;
import android.os.Bundle;
import android.support.v7.app.AppCompatActivity;
import android.support.v7.widget.DividerItemDecoration;
import android.support.v7.widget.GridLayoutManager;
import android.support.v7.widget.LinearLayoutManager;
import android.support.v7.widget.RecyclerView;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.AdapterView;


public class MainActivity extends AppCompatActivity implements AdapterView.OnItemClickListener
{
    private static final String TAG = "avosavis";

    /// représente la liste affichée
    private AvisAdapter adapter;

    /// request codes, voir startActivityForResult et onActivityResult
    private static final int RQ_EDIT_AVIS = 1;

    @Override
    protected void onCreate(Bundle savedInstanceState)
    {
        // mettre en place l'interface
        super.onCreate(savedInstanceState);
        setContentView(R.layout.main_activity);

        // liste des éléments, elle vient de l'application
        AvosAvisApplication app = (AvosAvisApplication) getApplicationContext();
        ArrayList<Avis> liste = app.getListe();

        // récupérer la liste
        RecyclerView recyclerView = (RecyclerView) findViewById(R.id.list);
        recyclerView.setHasFixedSize(true);

        // disposition des éléments
        LinearLayoutManager layoutManager = new LinearLayoutManager(this);
        //LinearLayoutManager layoutManager = new GridLayoutManager(this, 2);
        recyclerView.setLayoutManager(layoutManager);

        // ligne de séparation entre éléments
        DividerItemDecoration dividerItemDecoration =
            new DividerItemDecoration(recyclerView.getContext(), layoutManager.getOrientation());
        recyclerView.addItemDecoration(dividerItemDecoration);

        // adaptateur pour la liste
        adapter = new AvisAdapter(liste, this);
        recyclerView.setAdapter(adapter);

        // générer un menu contextuel sur chaque élément de la liste
        registerForContextMenu(recyclerView);
    }


    /**
     * Cette méthode est appelée quand on revient dans cette activité après avoir appelé une
     * autre par startActivityForResult(intent, requestCode).
     * @param requestCode : celui qui avait été passé à startActivityForResult
     * @param resultCode : RESULT_OK (l'uti a validé l'autre activité) ou RESULT_CANCELED (l'uti a fait back ou annuler), voir aussi setResult(resultCode)
     * @param data : un intent qui serait fourni par l'activité appelée
     */
    @Override
    protected void onActivityResult(int requestCode, int resultCode, Intent data)
    {
        Log.i(TAG, "MainActivity.onActivityResult("+requestCode+", "+resultCode+", ...)");
        if (resultCode == RESULT_CANCELED) return;

        // prévenir l'adaptateur que la liste a changé
        adapter.notifyDataSetChanged();

        // effacer la sélection
        adapter.clearSelection();
    }


    /**
     * appelée quand on clique sur l'un des items de la liste
     * @param position : le n° de l'item dans la liste
     * @param id : identifiant de l'item dans la liste (=position pour un ArrayAdapter)
     */
    @Override
    public void onItemClick(AdapterView<?> parent, View v, int position, long id)
    {
        onMenuEditer(position);
    }


    /**
     * menu nouveau => rajouter un élément dans la liste
     */
    private void onMenuNouveau()
    {
        // lancer l'activité d'édition sans identifiant
        Intent intent = new Intent(this, EditActivity.class);
        startActivityForResult(intent, RQ_EDIT_AVIS);
    }


    /**
     * lance l'édition de l'item en question
     * @param identifiant de l'item
     */
    private void onMenuEditer(final long identifiant)
    {
        // TODO lancer l'activité d'édition en fournissant l'identifiant de l'item à éditer, utiliser EditActivity.PARAM_IDENTIFIANT
    }


    /**
     * supprime l'item en question
     * @param identifiant de l'item
     */
    @SuppressWarnings("unused")
    private void onMenuSupprimer(final long identifiant)
    {
        // TODO recopier ce qu'il y a dans EditActivity.onSupprimer et adapter un peu

        // effacer la sélection
        adapter.clearSelection();
    }


    /**
     * appelée pour créer le menu de l'activité
     */
    @Override
    public boolean onCreateOptionsMenu(Menu menu)
    {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.main, menu);
        return true;
    }

    /**
     * appelée quand on clique sur un élément de menu
     */
    @Override
    public boolean onOptionsItemSelected(MenuItem item)
    {
        // selon l'item de menu qui est sélectionné, appeler la méthode concernée
        switch (item.getItemId()) {

        case R.id.nouveau:
            // l'utilisateur a choisi le menu nouveau : ajouter un nouvel élément dans la liste
            onMenuNouveau();
            return true;
        }
        return super.onOptionsItemSelected(item);
    }
}
